package com.cicdi.notify;

import com.cicdi.notify.template.Template;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * @author xueye
 */
public class DefaultNotifierManager implements NotifierManager {
    private final Map<String, Map<String, NotifierProvider>> providers = new ConcurrentHashMap<>();

    private Map<String, Notifier> notifiers = new ConcurrentHashMap<>();

    private NotifyConfigManager configManager;

//    private EventBus eventBus;

    public DefaultNotifierManager(NotifyConfigManager manager/*, EventBus eventBus*/) {
        this.configManager = manager;
//        this.eventBus = eventBus;
    }

    protected NotifierProperties getProperties(NotifyType notifyType, String id) {
        return configManager.getNotifyConfig(notifyType, id);
    }

    public void reload(String id) {
        Notifier notifier = notifiers.remove(id);
        if (null != notifier) {
            notifier.close();
        }
    }

    protected Notifier createNotifier(NotifierProperties properties) {
        Map<String, NotifierProvider> providerMap = providers.get(properties.getType());
        if (null == providerMap) {
            throw new UnsupportedOperationException("不支持的通知类型: " + properties.getType());
        }
        NotifierProvider provider = providerMap.get(properties.getProvider());
        if (null == provider) {
            throw new UnsupportedOperationException("不支持的服务商: " + properties.getProvider());
        }
        Notifier<? extends Template> notifier1 = provider.createNotifier(properties);
        Notifier notifier2 = notifiers.put(properties.getId(), notifier1);
        if (null != notifier2) {
            notifier2.close();
        }
        return notifier1;
    }

    @Override
    public Notifier getNotifier(NotifyType type, String id) {
        Notifier notifier = notifiers.get(id);
        if (null == notifier) {
            notifier = createNotifier(getProperties(type, id));
        }
        return notifier;
    }

    @Override
    public void registerProvider(NotifierProvider provider) {
        providers.computeIfAbsent(provider.getType().getId(), ignore -> new ConcurrentHashMap<>())
                .put(provider.getProvider().getId(), provider);
    }

}
