package com.cicdi.notify.sms;

import com.cicdi.notify.*;
import com.cicdi.notify.sms.aliyun.AliyunSmsNotifierProvider;
import com.cicdi.notify.sms.telecom.TelecomSmsNotifierProvider;
import com.cicdi.notify.template.AbstractTemplateManager;
import com.cicdi.notify.template.Template;
import com.cicdi.notify.template.TemplateManager;
import com.cicdi.notify.template.TemplateProperties;
import org.junit.Test;

import java.util.HashMap;
import java.util.Map;

/**
 * @author xueye
 */
public class TelecomSmsTest {
    @Test
    public void test() {
        // 通知器配置管理器
        NotifyConfigManager notifyConfigManager = new NotifyConfigManager() {
            @Override
            public NotifierProperties getNotifyConfig(NotifyType notifyType, String configId) {
                NotifierProperties notifierProperties = new NotifierProperties();
                notifierProperties.setType(DefaultNotifyType.sms.getId());
                notifierProperties.setProvider(SmsProvider.telecom.getId());
                notifierProperties.setId("12");

                Map<String, Object> config = new HashMap<>();
                config.put("serviceUrl", "http://www.js139.com.cn:8022/hysms/SendMsg");
                config.put("userId", "HYjlzx");
                config.put("password", "5CA45EA4944D2C32567E8DBBDDBD65DD");

                notifierProperties.setConfiguration(config);

                return notifierProperties;
            }
        };

        // 模板管理器
        TemplateManager templateManager = new AbstractTemplateManager() {
            @Override
            protected TemplateProperties getProperties(NotifyType type, String id) {
                TemplateProperties templateProperties = new TemplateProperties();
                templateProperties.setType(DefaultNotifyType.sms.getId());
                templateProperties.setProvider(SmsProvider.telecom.getId());

                templateProperties.setTemplate("{\"text\":\"Hello\",\"mobile\":\"18605120786\"}");

                return templateProperties;
            }
        };

        NotifierManager notifierManager = new DefaultNotifierManager(notifyConfigManager);

        // register
        AliyunSmsNotifierProvider aliyunSmsNotifierProvider = new AliyunSmsNotifierProvider(templateManager);
        TelecomSmsNotifierProvider telecomSmsNotifierProvider = new TelecomSmsNotifierProvider(templateManager);

        notifierManager.registerProvider(aliyunSmsNotifierProvider);
        notifierManager.registerProvider(telecomSmsNotifierProvider);

        templateManager.register(aliyunSmsNotifierProvider);
        templateManager.register(telecomSmsNotifierProvider);

        Notifier<Template> notifier = notifierManager.getNotifier(DefaultNotifyType.sms, "123");
        notifier.send(templateManager.getTemplate(DefaultNotifyType.sms, "124"), new HashMap<>());
    }
}
